==> mgb-0.5.4.1-de.zip: language/lang_install.php <==
<?php
// DO NOT REMOVE THIS COPYRIGHT //
//
// MGB v.null.fuenf (0.5.4.1) (C) by Jrgen Grneisl
// Visit me on http://www.tv-kritik.net/mgb/index.php
//
// This Guestbook is licensed under GNU GPL. Feel free to use, copy, share or modify it. :)

//lang_install.php - Sprachvariablen fr die Installation

////////////////////
// DEUTSCH v1.0.1 //
////////////////////

// Allgemeine Variablen

$lang['license']		= "Mit der Installation und anschlieenden Nutzung dieses Gstebuches,<br>stimmen Sie der GNU GPL Lizenz fr freie Software zu.";

$lang['title']		= "MGB v.null.fuenf (0.5.4) -- Installation";
$lang['greetz']		= "Willkommen zur Installation des MGB v.null.fnf. Ich mchte mich herzlich bei<br>Dir bedanken da Du mein Gstebuch gewhlt hast :) Die Installation dauert<br>nur ein paar Minuten, und danach ist Dein Gstebuch sofort einsatzbereit!";
$lang['instructions']	= "Bitte flle alle Felder aus! Merke Dir das Passwort gut, denn<br>das Passwort wird als md5 Hashwert gespeichert, und kann<br>nicht wieder zurckgewandelt werden.";

$lang['password']	= "Passwort";
$lang['hpname']		= "Name der Homepage";
$lang['hpaddress']	= "Adresse der Homepage";
$lang['gbpath']		= "Pfad zum Gstebuch";
$lang['email']		= "eMail";

$lang['tables']		= "Folgende Tabellen werden erstellt";
$lang['button_value']	= "Jetzt installieren";

$lang['failure']		= "Alle Felder mssen ausgefllt werden!";
$lang['email_failure']	= "Die angegebene eMail Adresse ist ungltig!";
$lang['success']		= "Das MGB v.null.fnf (0.5.4) wurde erfolgreich installiert! :) Bitte lsche jetzt die ''install.php''!";
$lang['install_failure'] = "Es ist ein Fehler bei der Verbindung zur Datenbank aufgetreten. berprfe die 'config.php' ob Du alle Daten<br>fr die Verbindung zur Datenbank richtig eingegeben hast.";
$lang['to_gb']		= "Zum Gstebuch";
$lang['to_admin']	= "Zur Administration und das erste mal einloggen";
$lang['hf']		= "Viel Spa wnscht";

?>

==> mgb-0.5.4.2-de.zip: language/lang_install.php <==
<?php
	/*
	MGB 0.5.4.2
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

//lang_install.php - Sprachvariablen fr die Installation

////////////////////
// DEUTSCH v1.0.1 //
////////////////////

// Allgemeine Variablen

$lang['license']		= "Mit der Installation und anschlieenden Nutzung dieses Gstebuches,<br>stimmen Sie der GNU GPL Lizenz fr freie Software zu.";

$lang['title']		= "MGB v.null.fuenf (0.5.4.2) -- Installation";
$lang['greetz']		= "Willkommen zur Installation des MGB v.null.fnf. Ich mchte mich herzlich bei<br>Dir bedanken da Du mein Gstebuch gewhlt hast :) Die Installation dauert<br>nur ein paar Minuten, und danach ist Dein Gstebuch sofort einsatzbereit!";
$lang['instructions']	= "Bitte flle alle Felder aus! Merke Dir das Passwort gut, denn<br>das Passwort wird als md5 Hashwert gespeichert, und kann<br>nicht wieder zurckgewandelt werden.";

$lang['password']	= "Passwort";
$lang['hpname']		= "Name der Homepage";
$lang['hpaddress']	= "Adresse der Homepage";
$lang['gbpath']		= "Pfad zum Gstebuch";
$lang['email']		= "eMail";

$lang['tables']		= "Folgende Tabellen werden erstellt";
$lang['button_value']	= "Jetzt installieren";

$lang['failure']		= "Alle Felder mssen ausgefllt werden!";
$lang['email_failure']	= "Die angegebene eMail Adresse ist ungltig!";
$lang['success']		= "Das MGB v.null.fnf (0.5.4.2) wurde erfolgreich installiert! :) Bitte lsche jetzt die ''install.php''!";
$lang['install_failure'] = "Es ist ein Fehler bei der Verbindung zur Datenbank aufgetreten. berprfe die 'config.php' ob Du alle Daten<br>fr die Verbindung zur Datenbank richtig eingegeben hast.";
$lang['to_gb']		= "Zum Gstebuch";
$lang['to_admin']	= "Zur Administration und das erste mal einloggen";
$lang['hf']		= "Viel Spa wnscht";

?>
